Documentation
¶
Index ¶
- Variables
- func AutoUpdate(allowTest bool)
- func Busy()
- func BusyAdd(n uint64)
- func BusyState() uint64
- func BusySub(n uint64)
- func Fetch(projectName, curTag, os, arch string, ...) error
- func GetUpdate(projectName, curTag, os, arch string) (string, string, string, error)
- func RunAutoUpdateCheck() bool
- func SetRestartCallback(cb func() error)
- func SignalVersion(git, build string)
- func Unbusy()
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func AutoUpdate ¶
func AutoUpdate(allowTest bool)
func RunAutoUpdateCheck ¶
func RunAutoUpdateCheck() bool
RunAutoUpdateCheck will perform the update check, update the executable and return false if no update was performed. In case of update the program should restart and RunAutoUpdateCheck() should not return, but if it does, it'll return true.
func SetRestartCallback ¶
func SetRestartCallback(cb func() error)
func SignalVersion ¶
func SignalVersion(git, build string)
SignalVersion is called when seeing another peer running the same software to notify of its version. This will check if the peer is updated compared to us, and call RunAutoUpdateCheck() if necessary
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.